from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Int

Tetyper_Py_V0_1_0 = CommandToolBuilder(tool="TETyper.py", base_command=["TETyper.py"], inputs=[ToolInput(tag="in_out_prefix", input_type=String(optional=True), prefix="--outprefix", doc=InputDocumentation(doc="Prefix to use for output files. Required.")), ToolInput(tag="in_ref", input_type=String(optional=True), prefix="--ref", doc=InputDocumentation(doc="Reference sequence in fasta format. If not already\nindexed with bwa, this will be created automatically.\nA blast database is also required, again this will be\ncreated automatically if it does not already exist.\nRequired.")), ToolInput(tag="in_ref_db", input_type=File(optional=True), prefix="--refdb", doc=InputDocumentation(doc="Blast database corresponding to reference file (this\nargument is only needed if the blast database was\ncreated with a different name).")), ToolInput(tag="in_fq_one", input_type=Int(optional=True), prefix="--fq1", doc=InputDocumentation(doc="Forward reads. Can be gzipped.")), ToolInput(tag="in_fq_two", input_type=Int(optional=True), prefix="--fq2", doc=InputDocumentation(doc="Reverse reads. Can be gzipped.")), ToolInput(tag="in_fq_one_two", input_type=Int(optional=True), prefix="--fq12", doc=InputDocumentation(doc="Interleaved forward and reverse reads.")), ToolInput(tag="in_bam", input_type=File(optional=True), prefix="--bam", doc=InputDocumentation(doc="Bam file containing reads mapped to the given\nreference. If the reads have already been mapped, this\noption saves time compared to specifying the reads in\nfastq format. If this option is specified then --fq*\nare ignored.")), ToolInput(tag="in_assembly", input_type=String(optional=True), prefix="--assembly", doc=InputDocumentation(doc="Use this assembly (fasta format) for detecting\nstructural variants instead of generating a new one.\nThis option saves time if an assembly is already\navailable.")), ToolInput(tag="in_spades_params", input_type=String(optional=True), prefix="--spades_params", doc=InputDocumentation(doc="Additional parameters for running spades assembly.\nEnclose in quotes and precede with a space. Default: '\n--cov-cutoff auto --disable-rr'. Ignored if --assembly\nis specified.")), ToolInput(tag="in_struct_profiles", input_type=File(optional=True), prefix="--struct_profiles", doc=InputDocumentation(doc="File containing known structural variants. Tab\nseparated format with two columns. First column is\nvariant name. Second column contains a list of\nsequence ranges representing deletions relative to the\nreference, or 'none' for no deletions. Each range\nshould be written as 'startpos-endpos', with multiple\nranges ordered by start position and separated by a\n'|' with no extra whitespace.")), ToolInput(tag="in_snp_profiles", input_type=File(optional=True), prefix="--snp_profiles", doc=InputDocumentation(doc="File containing known SNP profiles. Tab separated\nformat with three columns. First column: variant name,\nsecond column: homozygous SNPs, third column:\nheterozygous SNPs. SNPs should be written as\n'refPOSalt', where 'POS' is the position of that SNP\nwithin the reference, 'ref' is the reference base at\nthat position (A, C, G or T), and 'alt' is the variant\nbase at that position (A, C, G or T for a homozygous\nSNP; M, R, W, S, Y or K for a heterozygous SNP).\nMultiple SNPs of the same type (homozygous or\nheterozygous) should be ordered by position and\nseparated by a '|'. 'none' indicates no SNPs of the\ngiven type.")), ToolInput(tag="in_flank_len", input_type=Int(optional=True), prefix="--flank_len", doc=InputDocumentation(doc="Length of flanking region to extract. Required.")), ToolInput(tag="in_min_reads", input_type=Int(optional=True), prefix="--min_reads", doc=InputDocumentation(doc="Minimum read number for including a specific flanking\nsequence. Default 10.")), ToolInput(tag="in_min_each_strand", input_type=Int(optional=True), prefix="--min_each_strand", doc=InputDocumentation(doc="Minimum read number for each strand for including a\nspecific flanking sequence. Default 1.")), ToolInput(tag="in_min_mapped_len", input_type=Int(optional=True), prefix="--min_mapped_len", doc=InputDocumentation(doc="Minimum length of mapping for a read to be used in\ndetermining flanking sequences. Higher values are more\nrobust to spurious mapping. Lower values will recover\nmore reads. Default 30.")), ToolInput(tag="in_min_qual", input_type=Int(optional=True), prefix="--min_qual", doc=InputDocumentation(doc="Minimum quality value across extracted flanking\nsequence. Default 10.")), ToolInput(tag="in_show_region", input_type=Int(optional=True), prefix="--show_region", doc=InputDocumentation(doc="Display presence/absence for a specific region of\ninterest within the reference (e.g. to display blaKPC\npresence/absence with the Tn4401b-1 reference, use\n'7202-8083')")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Number of threads to use for mapping and assembly\nsteps. Default: 1")), ToolInput(tag="in_verbosity", input_type=String(optional=True), prefix="--verbosity", doc=InputDocumentation(doc="Verbosity level for logging to stderr. 1 = ERROR, 2 =\nWARNING, 3 = INFO, 4 = DUBUG. Default: 3.")), ToolInput(tag="in_no_overwrite", input_type=File(optional=True), prefix="--no_overwrite", doc=InputDocumentation(doc="Flag to prevent accidental overwriting of previous\noutput files. In this mode, the pipeline checks for a\nlog file named according to the given output prefix.\nIf it exists then the pipeline exits without modifying\nany files.\n"))], outputs=[ToolOutput(tag="out_no_overwrite", output_type=File(optional=True), selector=InputSelector(input_to_select="in_no_overwrite", type_hint=File()), doc=OutputDocumentation(doc="Flag to prevent accidental overwriting of previous\noutput files. In this mode, the pipeline checks for a\nlog file named according to the given output prefix.\nIf it exists then the pipeline exits without modifying\nany files.\n"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Tetyper_Py_V0_1_0().translate("wdl", allow_empty_container=True)

